pub struct AttributesEx3 { /* private fields */ }Available on crate feature
vanilla only.Expand description
This type is not sent over the network, but is used in the game in another way.
Auto generated from the original wowm in file wow_message_parser/wowm/world/external/external_spell_1_12.wowm:120:
flag AttributesEx3 : u32 {
NONE = 0x00;
PVP_ENABLING = 0x00000001;
NO_PROC_EQUIP_REQUIREMENT = 0x00000002;
NO_CASTING_BAR_TEXT = 0x00000004;
COMPLETELY_BLOCKED = 0x00000008;
NO_RES_TIMER = 0x00000010;
NO_DURABILITY_LOSS = 0x00000020;
NO_AVOIDANCE = 0x00000040;
DOT_STACKING_RULE = 0x00000080;
ONLY_ON_PLAYER = 0x00000100;
NOT_A_PROC = 0x00000200;
REQUIRES_MAIN_HAND_WEAPON = 0x00000400;
ONLY_BATTLEGROUNDS = 0x00000800;
ONLY_ON_GHOSTS = 0x00001000;
HIDE_CHANNEL_BAR = 0x00002000;
HIDE_IN_RAID_FILTER = 0x00004000;
NORMAL_RANGED_ATTACK = 0x00008000;
SUPPRESS_CASTER_PROCS = 0x00010000;
SUPPRESS_TARGET_PROCS = 0x00020000;
ALWAYS_HIT = 0x00040000;
INSTANT_TARGET_PROCS = 0x00080000;
ALLOW_AURA_WHILE_DEAD = 0x00100000;
ONLY_PROC_OUTDOORS = 0x00200000;
CASTING_CANCELS_AUTOREPEAT = 0x00400000;
NO_DAMAGE_HISTORY = 0x00800000;
REQUIRES_OFFHAND_WEAPON = 0x01000000;
TREAT_AS_PERIODIC = 0x02000000;
CAN_PROC_FROM_PROCS = 0x04000000;
ONLY_PROC_ON_CASTER = 0x08000000;
IGNORE_CASTER_AND_TARGET_RESTRICTIONS = 0x10000000;
IGNORE_CASTER_MODIFIERS = 0x20000000;
DO_NOT_DISPLAY_RANGE = 0x40000000;
NOT_ON_AOE_IMMUNE = 0x80000000;
}Implementations
Sourceimpl AttributesEx3
impl AttributesEx3
pub const NONE: u32 = 0u32
pub const PVP_ENABLING: u32 = 1u32
pub const NO_PROC_EQUIP_REQUIREMENT: u32 = 2u32
pub const NO_CASTING_BAR_TEXT: u32 = 4u32
pub const COMPLETELY_BLOCKED: u32 = 8u32
pub const NO_RES_TIMER: u32 = 16u32
pub const NO_DURABILITY_LOSS: u32 = 32u32
pub const NO_AVOIDANCE: u32 = 64u32
pub const DOT_STACKING_RULE: u32 = 128u32
pub const ONLY_ON_PLAYER: u32 = 256u32
pub const NOT_A_PROC: u32 = 512u32
pub const REQUIRES_MAIN_HAND_WEAPON: u32 = 1_024u32
pub const ONLY_BATTLEGROUNDS: u32 = 2_048u32
pub const ONLY_ON_GHOSTS: u32 = 4_096u32
pub const HIDE_CHANNEL_BAR: u32 = 8_192u32
pub const HIDE_IN_RAID_FILTER: u32 = 16_384u32
pub const NORMAL_RANGED_ATTACK: u32 = 32_768u32
pub const SUPPRESS_CASTER_PROCS: u32 = 65_536u32
pub const SUPPRESS_TARGET_PROCS: u32 = 131_072u32
pub const ALWAYS_HIT: u32 = 262_144u32
pub const INSTANT_TARGET_PROCS: u32 = 524_288u32
pub const ALLOW_AURA_WHILE_DEAD: u32 = 1_048_576u32
pub const ONLY_PROC_OUTDOORS: u32 = 2_097_152u32
pub const CASTING_CANCELS_AUTOREPEAT: u32 = 4_194_304u32
pub const NO_DAMAGE_HISTORY: u32 = 8_388_608u32
pub const REQUIRES_OFFHAND_WEAPON: u32 = 16_777_216u32
pub const TREAT_AS_PERIODIC: u32 = 33_554_432u32
pub const CAN_PROC_FROM_PROCS: u32 = 67_108_864u32
pub const ONLY_PROC_ON_CASTER: u32 = 134_217_728u32
pub const IGNORE_CASTER_AND_TARGET_RESTRICTIONS: u32 = 268_435_456u32
pub const IGNORE_CASTER_MODIFIERS: u32 = 536_870_912u32
pub const DO_NOT_DISPLAY_RANGE: u32 = 1_073_741_824u32
pub const NOT_ON_AOE_IMMUNE: u32 = 2_147_483_648u32
pub const fn new(inner: u32) -> AttributesEx3
pub const fn empty() -> AttributesEx3
pub const fn is_empty(&self) -> bool
pub const fn all() -> AttributesEx3
pub const fn is_pvp_enabling(&self) -> bool
pub const fn new_pvp_enabling() -> AttributesEx3
pub fn set_pvp_enabling(&mut self) -> AttributesEx3
pub fn clear_pvp_enabling(&mut self) -> AttributesEx3
pub const fn is_no_proc_equip_requirement(&self) -> bool
pub const fn new_no_proc_equip_requirement() -> AttributesEx3
pub fn set_no_proc_equip_requirement(&mut self) -> AttributesEx3
pub fn clear_no_proc_equip_requirement(&mut self) -> AttributesEx3
pub const fn is_no_casting_bar_text(&self) -> bool
pub const fn new_no_casting_bar_text() -> AttributesEx3
pub fn set_no_casting_bar_text(&mut self) -> AttributesEx3
pub fn clear_no_casting_bar_text(&mut self) -> AttributesEx3
pub const fn is_completely_blocked(&self) -> bool
pub const fn new_completely_blocked() -> AttributesEx3
pub fn set_completely_blocked(&mut self) -> AttributesEx3
pub fn clear_completely_blocked(&mut self) -> AttributesEx3
pub const fn is_no_res_timer(&self) -> bool
pub const fn new_no_res_timer() -> AttributesEx3
pub fn set_no_res_timer(&mut self) -> AttributesEx3
pub fn clear_no_res_timer(&mut self) -> AttributesEx3
pub const fn is_no_durability_loss(&self) -> bool
pub const fn new_no_durability_loss() -> AttributesEx3
pub fn set_no_durability_loss(&mut self) -> AttributesEx3
pub fn clear_no_durability_loss(&mut self) -> AttributesEx3
pub const fn is_no_avoidance(&self) -> bool
pub const fn new_no_avoidance() -> AttributesEx3
pub fn set_no_avoidance(&mut self) -> AttributesEx3
pub fn clear_no_avoidance(&mut self) -> AttributesEx3
pub const fn is_dot_stacking_rule(&self) -> bool
pub const fn new_dot_stacking_rule() -> AttributesEx3
pub fn set_dot_stacking_rule(&mut self) -> AttributesEx3
pub fn clear_dot_stacking_rule(&mut self) -> AttributesEx3
pub const fn is_only_on_player(&self) -> bool
pub const fn new_only_on_player() -> AttributesEx3
pub fn set_only_on_player(&mut self) -> AttributesEx3
pub fn clear_only_on_player(&mut self) -> AttributesEx3
pub const fn is_not_a_proc(&self) -> bool
pub const fn new_not_a_proc() -> AttributesEx3
pub fn set_not_a_proc(&mut self) -> AttributesEx3
pub fn clear_not_a_proc(&mut self) -> AttributesEx3
pub const fn is_requires_main_hand_weapon(&self) -> bool
pub const fn new_requires_main_hand_weapon() -> AttributesEx3
pub fn set_requires_main_hand_weapon(&mut self) -> AttributesEx3
pub fn clear_requires_main_hand_weapon(&mut self) -> AttributesEx3
pub const fn is_only_battlegrounds(&self) -> bool
pub const fn new_only_battlegrounds() -> AttributesEx3
pub fn set_only_battlegrounds(&mut self) -> AttributesEx3
pub fn clear_only_battlegrounds(&mut self) -> AttributesEx3
pub const fn is_only_on_ghosts(&self) -> bool
pub const fn new_only_on_ghosts() -> AttributesEx3
pub fn set_only_on_ghosts(&mut self) -> AttributesEx3
pub fn clear_only_on_ghosts(&mut self) -> AttributesEx3
pub const fn is_hide_channel_bar(&self) -> bool
pub const fn new_hide_channel_bar() -> AttributesEx3
pub fn set_hide_channel_bar(&mut self) -> AttributesEx3
pub fn clear_hide_channel_bar(&mut self) -> AttributesEx3
pub const fn is_hide_in_raid_filter(&self) -> bool
pub const fn new_hide_in_raid_filter() -> AttributesEx3
pub fn set_hide_in_raid_filter(&mut self) -> AttributesEx3
pub fn clear_hide_in_raid_filter(&mut self) -> AttributesEx3
pub const fn is_normal_ranged_attack(&self) -> bool
pub const fn new_normal_ranged_attack() -> AttributesEx3
pub fn set_normal_ranged_attack(&mut self) -> AttributesEx3
pub fn clear_normal_ranged_attack(&mut self) -> AttributesEx3
pub const fn is_suppress_caster_procs(&self) -> bool
pub const fn new_suppress_caster_procs() -> AttributesEx3
pub fn set_suppress_caster_procs(&mut self) -> AttributesEx3
pub fn clear_suppress_caster_procs(&mut self) -> AttributesEx3
pub const fn is_suppress_target_procs(&self) -> bool
pub const fn new_suppress_target_procs() -> AttributesEx3
pub fn set_suppress_target_procs(&mut self) -> AttributesEx3
pub fn clear_suppress_target_procs(&mut self) -> AttributesEx3
pub const fn is_always_hit(&self) -> bool
pub const fn new_always_hit() -> AttributesEx3
pub fn set_always_hit(&mut self) -> AttributesEx3
pub fn clear_always_hit(&mut self) -> AttributesEx3
pub const fn is_instant_target_procs(&self) -> bool
pub const fn new_instant_target_procs() -> AttributesEx3
pub fn set_instant_target_procs(&mut self) -> AttributesEx3
pub fn clear_instant_target_procs(&mut self) -> AttributesEx3
pub const fn is_allow_aura_while_dead(&self) -> bool
pub const fn new_allow_aura_while_dead() -> AttributesEx3
pub fn set_allow_aura_while_dead(&mut self) -> AttributesEx3
pub fn clear_allow_aura_while_dead(&mut self) -> AttributesEx3
pub const fn is_only_proc_outdoors(&self) -> bool
pub const fn new_only_proc_outdoors() -> AttributesEx3
pub fn set_only_proc_outdoors(&mut self) -> AttributesEx3
pub fn clear_only_proc_outdoors(&mut self) -> AttributesEx3
pub const fn is_casting_cancels_autorepeat(&self) -> bool
pub const fn new_casting_cancels_autorepeat() -> AttributesEx3
pub fn set_casting_cancels_autorepeat(&mut self) -> AttributesEx3
pub fn clear_casting_cancels_autorepeat(&mut self) -> AttributesEx3
pub const fn is_no_damage_history(&self) -> bool
pub const fn new_no_damage_history() -> AttributesEx3
pub fn set_no_damage_history(&mut self) -> AttributesEx3
pub fn clear_no_damage_history(&mut self) -> AttributesEx3
pub const fn is_requires_offhand_weapon(&self) -> bool
pub const fn new_requires_offhand_weapon() -> AttributesEx3
pub fn set_requires_offhand_weapon(&mut self) -> AttributesEx3
pub fn clear_requires_offhand_weapon(&mut self) -> AttributesEx3
pub const fn is_treat_as_periodic(&self) -> bool
pub const fn new_treat_as_periodic() -> AttributesEx3
pub fn set_treat_as_periodic(&mut self) -> AttributesEx3
pub fn clear_treat_as_periodic(&mut self) -> AttributesEx3
pub const fn is_can_proc_from_procs(&self) -> bool
pub const fn new_can_proc_from_procs() -> AttributesEx3
pub fn set_can_proc_from_procs(&mut self) -> AttributesEx3
pub fn clear_can_proc_from_procs(&mut self) -> AttributesEx3
pub const fn is_only_proc_on_caster(&self) -> bool
pub const fn new_only_proc_on_caster() -> AttributesEx3
pub fn set_only_proc_on_caster(&mut self) -> AttributesEx3
pub fn clear_only_proc_on_caster(&mut self) -> AttributesEx3
pub const fn is_ignore_caster_and_target_restrictions(&self) -> bool
pub const fn new_ignore_caster_and_target_restrictions() -> AttributesEx3
pub fn set_ignore_caster_and_target_restrictions(&mut self) -> AttributesEx3
pub fn clear_ignore_caster_and_target_restrictions(&mut self) -> AttributesEx3
pub const fn is_ignore_caster_modifiers(&self) -> bool
pub const fn new_ignore_caster_modifiers() -> AttributesEx3
pub fn set_ignore_caster_modifiers(&mut self) -> AttributesEx3
pub fn clear_ignore_caster_modifiers(&mut self) -> AttributesEx3
pub const fn is_do_not_display_range(&self) -> bool
pub const fn new_do_not_display_range() -> AttributesEx3
pub fn set_do_not_display_range(&mut self) -> AttributesEx3
pub fn clear_do_not_display_range(&mut self) -> AttributesEx3
pub const fn is_not_on_aoe_immune(&self) -> bool
pub const fn new_not_on_aoe_immune() -> AttributesEx3
pub fn set_not_on_aoe_immune(&mut self) -> AttributesEx3
pub fn clear_not_on_aoe_immune(&mut self) -> AttributesEx3
pub const fn as_int(&self) -> u32